==> ejc-law-impl-3.0.0-20221018.103102-9-sources.jar: com/ejianc/business/law/bean/LedgerEntity.java <==
package com.ejianc.business.law.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 案件台账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_law_ledger")
public class LedgerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="operator_code")
    private String operatorCode; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="case_id")
    private Long caseId; // 案件id
    @TableField(value="case_code")
    private String caseCode; // 案件编号
    @TableField(value="cognizance_date")
    private Date cognizanceDate; // 收案日期
    @TableField(value="end_date")
    private Date endDate; // 结案日期
    @TableField(value="sue_amount")
    private BigDecimal sueAmount; // 起诉金额（元）
    @TableField(value="end_amount")
    private BigDecimal endAmount; // 结案金额
    @TableField(value="department_id")
    private Long departmentId; // 涉案项目部
    @TableField(value="department_name")
    private String departmentName; // 涉案项目部名称
    @TableField(value="project_id")
    private Long projectId; // 工程
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="contract_cost")
    private BigDecimal contractCost; // 合同造价（万元）
    @TableField(value="dispute_type")
    private String disputeType; // 纠纷类型
    @TableField(value="dispute_type_name")
    private String disputeTypeName; // 纠纷类型名称
    @TableField(value="lab_dispute_type")
    private Long labDisputeType; // 劳务类纠纷
    @TableField(value="lab_dispute_type_name")
    private String labDisputeTypeName; // 劳务类纠纷名称
    @TableField(value="case_state")
    private Long caseState; // 案件状态
    @TableField(value="case_state_name")
    private String caseStateName; // 案件状态名称
    @TableField(value="case_result_id")
    private Long caseResultId; // 案件结果id
    @TableField(value="case_result_name")
    private String caseResultName; // 案件结果
    @TableField(value="pay_state")
    private Long payState; // 付款状态
    @TableField(value="pay_state_name")
    private String payStateName; // 付款状态名称
    @TableField(value="hear_count")
    private Integer hearCount; // 审理次数
    @TableField(value="plaintiff_id")
    private Long plaintiffId; // 原告id
    @TableField(value="plaintiff_name")
    private String plaintiffName; // 原告
    @TableField(value="other_defendant_id")
    private Long otherDefendantId; // 其他被告id
    @TableField(value="other_defendant_name")
    private String otherDefendantName; // 其他被告
    @TableField(value="third_party_id")
    private Long thirdPartyId; // 第三人id
    @TableField(value="third_party_name")
    private String thirdPartyName; // 第三人
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getCaseId() {
        return caseId;
    }

    public void setCaseId(Long caseId) {
        this.caseId = caseId;
    }
    public String getCaseCode() {
        return caseCode;
    }

    public void setCaseCode(String caseCode) {
        this.caseCode = caseCode;
    }
    public Date getCognizanceDate() {
        return cognizanceDate;
    }

    public void setCognizanceDate(Date cognizanceDate) {
        this.cognizanceDate = cognizanceDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public BigDecimal getSueAmount() {
        return sueAmount;
    }

    public void setSueAmount(BigDecimal sueAmount) {
        this.sueAmount = sueAmount;
    }
    public BigDecimal getEndAmount() {
        return endAmount;
    }

    public void setEndAmount(BigDecimal endAmount) {
        this.endAmount = endAmount;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getContractCost() {
        return contractCost;
    }

    public void setContractCost(BigDecimal contractCost) {
        this.contractCost = contractCost;
    }
    public String getDisputeType() {
        return disputeType;
    }

    public void setDisputeType(String disputeType) {
        this.disputeType = disputeType;
    }
    public String getDisputeTypeName() {
        return disputeTypeName;
    }

    public void setDisputeTypeName(String disputeTypeName) {
        this.disputeTypeName = disputeTypeName;
    }
    public Long getLabDisputeType() {
        return labDisputeType;
    }

    public void setLabDisputeType(Long labDisputeType) {
        this.labDisputeType = labDisputeType;
    }
    public String getLabDisputeTypeName() {
        return labDisputeTypeName;
    }

    public void setLabDisputeTypeName(String labDisputeTypeName) {
        this.labDisputeTypeName = labDisputeTypeName;
    }
    public Long getCaseState() {
        return caseState;
    }

    public void setCaseState(Long caseState) {
        this.caseState = caseState;
    }
    public String getCaseStateName() {
        return caseStateName;
    }

    public void setCaseStateName(String caseStateName) {
        this.caseStateName = caseStateName;
    }
    public Long getCaseResultId() {
        return caseResultId;
    }

    public void setCaseResultId(Long caseResultId) {
        this.caseResultId = caseResultId;
    }
    public String getCaseResultName() {
        return caseResultName;
    }

    public void setCaseResultName(String caseResultName) {
        this.caseResultName = caseResultName;
    }
    public Long getPayState() {
        return payState;
    }

    public void setPayState(Long payState) {
        this.payState = payState;
    }
    public String getPayStateName() {
        return payStateName;
    }

    public void setPayStateName(String payStateName) {
        this.payStateName = payStateName;
    }
    public Integer getHearCount() {
        return hearCount;
    }

    public void setHearCount(Integer hearCount) {
        this.hearCount = hearCount;
    }
    public Long getPlaintiffId() {
        return plaintiffId;
    }

    public void setPlaintiffId(Long plaintiffId) {
        this.plaintiffId = plaintiffId;
    }
    public String getPlaintiffName() {
        return plaintiffName;
    }

    public void setPlaintiffName(String plaintiffName) {
        this.plaintiffName = plaintiffName;
    }
    public Long getOtherDefendantId() {
        return otherDefendantId;
    }

    public void setOtherDefendantId(Long otherDefendantId) {
        this.otherDefendantId = otherDefendantId;
    }
    public String getOtherDefendantName() {
        return otherDefendantName;
    }

    public void setOtherDefendantName(String otherDefendantName) {
        this.otherDefendantName = otherDefendantName;
    }
    public Long getThirdPartyId() {
        return thirdPartyId;
    }

    public void setThirdPartyId(Long thirdPartyId) {
        this.thirdPartyId = thirdPartyId;
    }
    public String getThirdPartyName() {
        return thirdPartyName;
    }

    public void setThirdPartyName(String thirdPartyName) {
        this.thirdPartyName = thirdPartyName;
    }
    
}

==> ejc-law-impl-3.0.0-20221107.141547-20-sources.jar: com/ejianc/business/law/bean/LedgerEntity.java <==
package com.ejianc.business.law.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 案件台账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_law_ledger")
public class LedgerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="operator_code")
    private String operatorCode; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="case_id")
    private Long caseId; // 案件id
    @TableField(value="case_code")
    private String caseCode; // 案件编号
    @TableField(value="cognizance_date")
    private Date cognizanceDate; // 收案日期
    @TableField(value="end_date")
    private Date endDate; // 结案日期
    @TableField(value="sue_amount")
    private BigDecimal sueAmount; // 起诉金额（元）
    @TableField(value="end_amount")
    private BigDecimal endAmount; // 结案金额
    @TableField(value="department_id")
    private Long departmentId; // 涉案项目部
    @TableField(value="department_name")
    private String departmentName; // 涉案项目部名称
    @TableField(value="project_id")
    private Long projectId; // 工程
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="contract_cost")
    private BigDecimal contractCost; // 合同造价（万元）
    @TableField(value="dispute_type")
    private String disputeType; // 纠纷类型
    @TableField(value="dispute_type_name")
    private String disputeTypeName; // 纠纷类型名称
    @TableField(value="lab_dispute_type")
    private Long labDisputeType; // 劳务类纠纷
    @TableField(value="lab_dispute_type_name")
    private String labDisputeTypeName; // 劳务类纠纷名称
    @TableField(value="case_state")
    private Long caseState; // 案件状态
    @TableField(value="case_state_name")
    private String caseStateName; // 案件状态名称
    @TableField(value="case_result_id")
    private Long caseResultId; // 案件结果id
    @TableField(value="case_result_name")
    private String caseResultName; // 案件结果
    @TableField(value="pay_state")
    private Long payState; // 付款状态
    @TableField(value="pay_state_name")
    private String payStateName; // 付款状态名称
    @TableField(value="hear_count")
    private Integer hearCount; // 审理次数
    @TableField(value="plaintiff_id")
    private Long plaintiffId; // 原告id
    @TableField(value="plaintiff_name")
    private String plaintiffName; // 原告
    @TableField(value="other_defendant_id")
    private Long otherDefendantId; // 其他被告id
    @TableField(value="other_defendant_name")
    private String otherDefendantName; // 其他被告
    @TableField(value="third_party_id")
    private Long thirdPartyId; // 第三人id
    @TableField(value="third_party_name")
    private String thirdPartyName; // 第三人
    @TableField(value = "frozen_id")
    private Long frozenId;//冻结id
    @TableField(value = "frozen_code")
    private String frozenCode;//冻结编号
    @TableField(value = "thaw_id")
    private Long thawId;//解冻id
    @TableField(value = "thaw_code")
    private String thawCode;//解冻编号
    @TableField(value = "info_id")
    private Long infoId;//审理id
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getCaseId() {
        return caseId;
    }

    public void setCaseId(Long caseId) {
        this.caseId = caseId;
    }
    public String getCaseCode() {
        return caseCode;
    }

    public void setCaseCode(String caseCode) {
        this.caseCode = caseCode;
    }
    public Date getCognizanceDate() {
        return cognizanceDate;
    }

    public void setCognizanceDate(Date cognizanceDate) {
        this.cognizanceDate = cognizanceDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public BigDecimal getSueAmount() {
        return sueAmount;
    }

    public void setSueAmount(BigDecimal sueAmount) {
        this.sueAmount = sueAmount;
    }
    public BigDecimal getEndAmount() {
        return endAmount;
    }

    public void setEndAmount(BigDecimal endAmount) {
        this.endAmount = endAmount;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getContractCost() {
        return contractCost;
    }

    public void setContractCost(BigDecimal contractCost) {
        this.contractCost = contractCost;
    }
    public String getDisputeType() {
        return disputeType;
    }

    public void setDisputeType(String disputeType) {
        this.disputeType = disputeType;
    }
    public String getDisputeTypeName() {
        return disputeTypeName;
    }

    public void setDisputeTypeName(String disputeTypeName) {
        this.disputeTypeName = disputeTypeName;
    }
    public Long getLabDisputeType() {
        return labDisputeType;
    }

    public void setLabDisputeType(Long labDisputeType) {
        this.labDisputeType = labDisputeType;
    }
    public String getLabDisputeTypeName() {
        return labDisputeTypeName;
    }

    public void setLabDisputeTypeName(String labDisputeTypeName) {
        this.labDisputeTypeName = labDisputeTypeName;
    }
    public Long getCaseState() {
        return caseState;
    }

    public void setCaseState(Long caseState) {
        this.caseState = caseState;
    }
    public String getCaseStateName() {
        return caseStateName;
    }

    public void setCaseStateName(String caseStateName) {
        this.caseStateName = caseStateName;
    }
    public Long getCaseResultId() {
        return caseResultId;
    }

    public void setCaseResultId(Long caseResultId) {
        this.caseResultId = caseResultId;
    }
    public String getCaseResultName() {
        return caseResultName;
    }

    public void setCaseResultName(String caseResultName) {
        this.caseResultName = caseResultName;
    }
    public Long getPayState() {
        return payState;
    }

    public void setPayState(Long payState) {
        this.payState = payState;
    }
    public String getPayStateName() {
        return payStateName;
    }

    public void setPayStateName(String payStateName) {
        this.payStateName = payStateName;
    }
    public Integer getHearCount() {
        return hearCount;
    }

    public void setHearCount(Integer hearCount) {
        this.hearCount = hearCount;
    }
    public Long getPlaintiffId() {
        return plaintiffId;
    }

    public void setPlaintiffId(Long plaintiffId) {
        this.plaintiffId = plaintiffId;
    }
    public String getPlaintiffName() {
        return plaintiffName;
    }

    public void setPlaintiffName(String plaintiffName) {
        this.plaintiffName = plaintiffName;
    }
    public Long getOtherDefendantId() {
        return otherDefendantId;
    }

    public void setOtherDefendantId(Long otherDefendantId) {
        this.otherDefendantId = otherDefendantId;
    }
    public String getOtherDefendantName() {
        return otherDefendantName;
    }

    public void setOtherDefendantName(String otherDefendantName) {
        this.otherDefendantName = otherDefendantName;
    }
    public Long getThirdPartyId() {
        return thirdPartyId;
    }

    public void setThirdPartyId(Long thirdPartyId) {
        this.thirdPartyId = thirdPartyId;
    }
    public String getThirdPartyName() {
        return thirdPartyName;
    }

    public void setThirdPartyName(String thirdPartyName) {
        this.thirdPartyName = thirdPartyName;
    }

    public Long getFrozenId() {
        return frozenId;
    }

    public void setFrozenId(Long frozenId) {
        this.frozenId = frozenId;
    }

    public String getFrozenCode() {
        return frozenCode;
    }

    public void setFrozenCode(String frozenCode) {
        this.frozenCode = frozenCode;
    }

    public Long getThawId() {
        return thawId;
    }

    public void setThawId(Long thawId) {
        this.thawId = thawId;
    }

    public String getThawCode() {
        return thawCode;
    }

    public void setThawCode(String thawCode) {
        this.thawCode = thawCode;
    }

    public Long getInfoId() {
        return infoId;
    }

    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
}
